@@ -21,7 +21,7 @@ This module implements generic functions for subscriptions
 """
 __version__ = "$Revision: 61009 $"
 # $Source$
-# $Id: SubscriptionTool.py 241715 2011-06-30 16:33:44Z yboussard $
+# $Id: SubscriptionTool.py 241867 2011-07-04 15:27:38Z yboussard $
 __docformat__ = 'restructuredtext'
 
 # Python imports
@@ -985,7 +985,8 @@ A change related to your subscription to "%(subscription_title)s" was found:
             content += str(brain.Title or brain.getId)
             content += " :\n"
             obj = brain.getObject()
-            if base_url == '':
+            
+            if base_url == '' or self.isVHMContext():
                 content += str(obj.absolute_url())
             else:
                 content += base_url
@@ -998,6 +999,19 @@ A change related to your subscription to "%(subscription_title)s" was found:
                            }
         return body
 
+    def isVHMContext(self):
+        VHM = False
+        try:
+            request = self.REQUEST
+            if 'PATH_INFO' in request \
+                   and 'VirtualHostRoot' in  request['PATH_INFO']:
+                ## VHM case
+                VHM = True
+        except:
+            pass
+        return VHM
+
+
     security.declareProtected(SubscriptionPermissions.ManageSubscriptionContent, 'mailing')
     def contactMailing(self, content, emails, from_email, subject, message):
         """Contact all subscribers concering some content"""
@@ -1017,7 +1031,7 @@ A change related to your subscription to "%(subscription_title)s" was found:
         portal_path = getToolByName(self, 'portal_url').getPortalPath()
         portal_path_length = len(portal_path)
         base_url = self.getBaseUrl()
-        if base_url == '':
+        if base_url == '' or self.isVHMContext():
             content_info += str(content.absolute_url()) + "\n\n"
         else:
             content_info += base_url + str(content.absolute_url_path()[portal_path_length:]) + "\n\n"
@@ -1060,7 +1074,7 @@ A change related to your subscription to "%(subscription_title)s" was found:
         portal_path = getToolByName(self, 'portal_url').getPortalPath()
         portal_path_length = len(portal_path)
         base_url = self.getBaseUrl()
-        if base_url == '':
+        if base_url == '' or self.isVHMContext():
             content_info += str(content.absolute_url()) + "\n\n"
         else:
             content_info += base_url + str(content.absolute_url_path()[portal_path_length:]) + "\n\n"
